@@ -29,9 +29,9 @@ class Client:
         self,
         request_strategy: RequestStrategy,
         *,
-        default_timeout: float = 20,
-        default_priority: Priority = Priority.NORMAL,
-        request_enricher: Optional[Callable[[Request], Request]] = None,
+        default_timeout: float,
+        default_priority: Priority,
+        request_enricher: Optional[Callable[[Request], Request]],
         metrics_collector: MetricsCollector,
     ):
         self._default_priority = default_priority
@@ -54,8 +54,8 @@ class Client:
         context = get_context()
         response_ctx = self._request_strategy.request(
             request,
-            context.deadline or deadline or Deadline.from_timeout(self._default_timeout),
-            context.priority or priority or self._default_priority,
+            deadline or context.deadline or Deadline.from_timeout(self._default_timeout),
+            self.normalize_priority(priority or self._default_priority, context.priority),
         )
         started_at = time.perf_counter()
         has_cancelled_during_request_sending = True
@@ -74,6 +74,19 @@ class Client:
                 self._metrics_collector.collect(request, None, elapsed)
             raise
 
+    @staticmethod
+    def normalize_priority(priority: "Priority", context_priority: Optional["Priority"]) -> "Priority":
+        if context_priority is None:
+            return priority
+
+        if priority == Priority.LOW and context_priority == Priority.HIGH:
+            return Priority.NORMAL
+
+        if priority == Priority.HIGH and context_priority == Priority.LOW:
+            return Priority.NORMAL
+
+        return priority
+
 
 def setup(
     *,
@@ -82,10 +95,10 @@ def setup(
     service_name: str = "unknown",
     safe_method_attempts_count: int = 3,
     unsafe_method_attempts_count: int = 3,
-    safe_method_delays_provider: Callable[[int], float] = linear_delays(),
-    unsafe_method_delays_provider: Callable[[int], float] = linear_delays(),
+    safe_method_delays_provider: Callable[[int], float] = linear_delays(delay_multiplier=0.1),
+    unsafe_method_delays_provider: Callable[[int], float] = linear_delays(delay_multiplier=0.05),
     response_classifier: Optional[ResponseClassifier] = None,
-    default_timeout: float = 60.0,
+    default_timeout: float = 20.0,
     default_priority: Priority = Priority.NORMAL,
     low_timeout_threshold: float = 0.005,
     emit_system_headers: bool = True,
