@@ -1,5 +1,5 @@
 import contextlib
-from typing import Any, Collection, Dict, Optional, Protocol
+from typing import Any, Collection, Dict, Mapping, Optional, Protocol, Union
 
 import multidict
 import yarl
@@ -7,7 +7,9 @@ import yarl
 EMPTY_HEADERS = multidict.CIMultiDictProxy[str](multidict.CIMultiDict[str]())
 
 
-def get_headers_to_enrich(headers: Optional[multidict.CIMultiDictProxy[str]]) -> multidict.CIMultiDict[str]:
+def get_headers_to_enrich(
+    headers: Optional[Union[Mapping[Union[str, multidict.istr], str], multidict.CIMultiDictProxy[str]]]
+) -> multidict.CIMultiDict[str]:
     return multidict.CIMultiDict[str](headers) if headers is not None else multidict.CIMultiDict[str]()
 
 
@@ -22,15 +24,15 @@ async def close_many(items: Collection[Closable]) -> None:
             await item.close()
 
 
-def substitute_path_parameters(url: yarl.URL, build_parameters: Optional[Dict[str, Any]] = None) -> yarl.URL:
-    if not build_parameters:
+def substitute_path_parameters(url: yarl.URL, parameters: Optional[Mapping[str, str]] = None) -> yarl.URL:
+    if not parameters:
         return url
 
     path = url.path
-    for name, value in build_parameters.items():
-        path = path.replace(f"{{{name}}}", str(value))
+    for name, value in parameters.items():
+        path = path.replace(f"{{{name}}}", value)
 
-    build_parameters = dict(
+    build_parameters: Dict[str, Any] = dict(
         scheme=url.scheme,
         authority=url.authority,
         user=url.user,
